@@ -138,7 +138,7 @@ def sign_in(url):
     try:
         cookies = krb_sign_on(url)
     except requests.exceptions.HTTPError as r:
-        raise SSOAuthException(r)
+        raise SSOAuthException(r) from None
     else:
         return cookies
 
