@@ -1,5 +1,5 @@
 ###############################################################################
-# (c) Copyright 2021 CERN for the benefit of the LHCb Collaboration           #
+# (c) Copyright 2021-2022 CERN for the benefit of the LHCb Collaboration      #
 #                                                                             #
 # This software is distributed under the terms of the GNU General Public      #
 # Licence version 3 (GPL Version 3), copied verbatim in the file "COPYING".   #
@@ -23,7 +23,7 @@ from hist import Hist
 
 @dataclass
 class CheckResult:
-    """Class for representing the return result of ntuple checks"""
+    """Class for representing the return result of ntuple checks."""
 
     check_type: str
     passed: bool
@@ -32,10 +32,13 @@ class CheckResult:
 
 
 def run_job_checks(checks_list, check_data, test_ntuple_path_list):
-    """
-    Run the checks listed for the given job, using data from an ntuple made earlier (by `lb-ap test`).
+    """Run the checks listed using data from ntuples.
 
-    Returns dict of CheckResult objects
+    Run a list of checks (can be a subset of all the checks defined in check_data).
+    Requires that the data ntuples are already created (eg. by `lb-ap test`).
+
+    Returns:
+        dict: CheckResult objects
     """
     check_results = {}
 
@@ -106,13 +109,18 @@ def num_entries(
     count,
     tree_pattern,
 ):
-    """Check that all matching TTree objects contain a minimum number of entries.
+    """Number of entries check.
 
-    :param filepath_list: List of paths to files to analyse
-    :param count: The minimum number of entries required
-    :param tree_pattern: A regular expression for the TTree objects to check
-    :returns: A CheckResult object, containing tree_data key/values:
-      * num_entries: the total number of events in the TTree
+    Check that all matching TTree objects contain a minimum number of entries.
+
+    Args:
+        filepath_list (list[file-like]): List of paths to files to analyse
+        count (int): The minimum number of entries required
+        tree_pattern (regex): A regular expression for the TTree objects to check
+
+    Returns:
+        A CheckResult object, which for each tree contains tree_data key/values:
+            num_entries: The total number of events in the TTree
     """
     result = CheckResult("num_entries", False)
     for filepath in filepath_list:
@@ -162,29 +170,34 @@ def range_check(
     mean_tolerance,
     std_tolerance,
 ):
-    """Check if there is at least one entry in the TTree object with a specific
-    variable falling in a pre-defined range. The histogram is then produced as output.
-    If the expected mean and standard deviation values are given in input, they are compared with the observed ones
-    and their agreement within the provided *_tolerance is checked.
-    It is possible to blind some regions.
+    """Range check.
 
-    :param filepath_list: List of paths to files to analyse
-    :param expression: Name of the variable (or expression depending on varibales in the TTree) to be checked
-    :param limits: Pre-defined range
-    :param n_bins: number of bins for the histogram
-    :param blind_ranges: regions to be blinded in the histogram
-    :param exp_mean: Expected mean value (optional)
-    :param exp_std: Expected standard deviation (optional)
-    :param mean_tolerance: Maximum shift tolerated between expected and observed mean values (optional)
-    :param std_tolerance: Maximum shift tolerated between expected and observed values of standard deviation (optional)
-    :param tree_pattern: A regular expression for the TTree object to check
-    :returns: A CheckResult object, containing tree_data key/values:
-      * histograms: filled 1D histogram of the quantity defined by the expression parameter
-      * num_entries: the total number of entries in the histogram (with blind ranges applied)
-      * mean: the mean of the histogram (approximated using binned data)
-      * variance: the variance of the histogram (approximated using binned data)
-      * stddev: the standard deviation of the histogram (approximated using binned data)
-      * num_entries_in_mean_window: the number of events falling in the exp_mean +- exp_std region (with blind ranges applied)
+    Check if there is at least one entry in the TTree object with a specific variable falling in a pre-defined range.
+    If the expected mean and standard deviation values are given in input, they are compared with the observed ones
+    and their agreement within the provided *_tolerance is checked. It is also possible to blind some regions.
+
+    Args:
+        filepath_list (list[file-like]): List of paths to files to analyse
+        expression (str): Name of the variable (or expression depending on varibales in the TTree) to be checked
+        limits (dict): Pre-defined range for x axis
+        n_bins (int): Number of bins for the histogram
+        blind_ranges (dict): Regions to be blinded in the histogram
+        exp_mean (float): Expected mean value (optional)
+        exp_std (float): Expected standard deviation (optional)
+        mean_tolerance (float): Maximum shift tolerated between expected and observed mean values (optional)
+        std_tolerance (float): Maximum shift tolerated between expected and observed values of standard deviation
+            (optional)
+        tree_pattern (regex): A regular expression for the TTree object to check
+
+    Returns:
+        A CheckResult object, which for each tree contains tree_data key/values:
+            histograms (list[Hist]): Filled 1D histogram of the quantity defined by the expression parameter
+            num_entries (float): The total number of entries in the histogram (with blind ranges applied)
+            mean (float): The mean of the histogram (approximated using binned data)
+            variance (float): The variance of the histogram (approximated using binned data)
+            stddev (float): The standard deviation of the histogram (approximated using binned data)
+            num_entries_in_mean_window (float): The number of events falling in the exp_mean +- exp_std region (with
+                blind ranges applied)
     """
     result = CheckResult("range", True)
     bin_centers = None
@@ -208,7 +221,7 @@ def range_check(
                         n_bins, limits["min"], limits["max"], name=expression
                     )
                     bin_centers = axis0.centers
-                    h = Hist(axis0)
+                    h = Hist(axis0, name=f"{key} {expression}")
                     result.tree_data[key]["histograms"] = [h]
                     result.tree_data[key]["num_entries"] = 0
                     result.tree_data[key]["mean"] = 0
@@ -287,7 +300,7 @@ def range_check(
                 variance = 0
             result.tree_data[key]["variance"] = variance
 
-            stddev = variance ** 0.5
+            stddev = variance**0.5
             result.tree_data[key]["stddev"] = stddev
 
             # Apply expected mean requirement
@@ -329,17 +342,22 @@ def range_check_nd(
     blind_ranges,
     tree_pattern,
 ):
-    """Produce 2-dimensional histograms of variables taken from a TTree object.
+    """N-dimensional range check.
 
-    :param filepath_list: List of paths to files to analyse
-    :param expressions: Name of the variables (or expressions) to be checked.
-    :param limits: Pre-defined ranges
-    :param n_bins: number of bins for the histogram
-    :param blind_ranges: regions to be blinded in the histogram
-    :param tree_pattern: A regular expression for the TTree object to check
-    :returns: A CheckResult object, containing tree_data key/values:
-      * histograms: a list of filled histograms of the quantities defined by the expression parameters
-      * num_entries: the total number of entries in the histogram (with blind ranges applied)
+    Produce 2-dimensional histograms of variables taken from a TTree object.
+
+    Args:
+        filepath_list (list[file-like]): List of paths to files to analyse
+        expressions (dict): Name of the variables (or expressions) to be checked.
+        limits (dict): Pre-defined ranges
+        n_bins (dict): Number of bins for the histogram
+        blind_ranges (dict): Regions to be blinded in the histogram
+        tree_pattern (regex): A regular expression for the TTree object to check
+
+    Returns:
+        A CheckResult object, which for each tree contains tree_data key/values:
+            histograms (list[Hist]): A list of filled histograms of the quantities defined by the expression parameters
+            num_entries (float): The total number of entries in the histogram (with blind ranges applied)
     """
     result = CheckResult("range_nd", True)
 
@@ -386,7 +404,11 @@ def range_check_nd(
                             limits[key_j]["max"],
                             name=expressions[key_j],
                         )
-                        h = Hist(axis0, axis1)
+                        h = Hist(
+                            axis0,
+                            axis1,
+                            name=f"{key} {expressions[key_i]}/{expressions[key_j]}",
+                        )
                         result.tree_data[key]["histograms"] += [h]
                     if length_expr == 3:
                         for key_i, key_j, key_k in combinations(
@@ -410,7 +432,12 @@ def range_check_nd(
                                 limits[key_k]["max"],
                                 name=expressions[key_k],
                             )
-                            h = Hist(axis0, axis1, axis2)
+                            h = Hist(
+                                axis0,
+                                axis1,
+                                axis2,
+                                name=f"{key} {expressions[key_i]}/{expressions[key_j]}/{expressions[key_k]}",
+                            )
                         result.tree_data[key]["histograms"] += [h]
 
                     result.tree_data[key]["num_entries"] = 0
@@ -517,16 +544,21 @@ def num_entries_per_invpb(
     tree_pattern,
     lumi_pattern,
 ):
-    """Check that the matching TTree objects contain a minimum number of entries per unit luminosity (pb-1).
+    """Number of entries per inverse picobarn check.
 
-    :param filepath_list: List of paths to files to analyse
-    :param count_per_invpb: The minimum number of entries per unit luminosity required
-    :param tree_pattern: A regular expression for the TTree objects to check
-    :param lumi_pattern: A regular expression for the TTree object containing the luminosity information
-    :returns: A CheckResult object, containing tree_data key/values:
-      * num_entries: the total number of events in the TTree
-      * lumi_invpb: the total luminosity, in inverse picobarns
-      * num_entries_per_invpb: the total number of events divided by the total luminosity
+    Check that the matching TTree objects contain a minimum number of entries per unit luminosity (pb-1).
+
+    Args:
+        filepath_list (list[file-like]): List of paths to files to analyse
+        count_per_invpb (float): The minimum number of entries per unit luminosity required
+        tree_pattern (regex): A regular expression for the TTree objects to check
+        lumi_pattern (regex): A regular expression for the TTree object containing the luminosity information
+
+    Returns:
+        A CheckResult object, which for each tree contains tree_data key/values:
+            num_entries (float): The total number of events in the TTree
+            lumi_invpb (float): The total luminosity, in inverse picobarns
+            num_entries_per_invpb (float): The total number of events divided by the total luminosity
     """
     result = CheckResult("num_entries_per_invpb", True)
 
@@ -568,7 +600,7 @@ def num_entries_per_invpb(
                         result.passed = False
                         break
 
-                    err_lumi_quad_sum = math.sqrt(numpy.sum(err_lumi_arr ** 2))
+                    err_lumi_quad_sum = math.sqrt(numpy.sum(err_lumi_arr**2))
                     if err_lumi_quad_sum / numpy.sum(lumi_arr) >= 1:
                         result.passed = False
                         result.messages += [
@@ -618,34 +650,38 @@ def range_check_bkg_subtracted(
     blind_ranges,
     tree_pattern,
 ):
-    """Check if there is at least one entry in the TTree object with a specific
-    variable falling in a pre-defined range. The background-subtracted histogram is then produced as output.
-    Background is subtracted assuming a linear distribution. In particular, signal ([m-s, m+s])
-    and background ([m-b-delta, m-b] U [m+b, m+b+delta]) windows have to be defined on a control variable.
-    Then, one histogram is created for events falling in the signal region and another histogram is created
-    for events falling in the background region.
-    The subtraction, using the proper scaling factor, is finally performed.
-    It is possible to blind some regions.
+    """Range check with background subtraction.
 
-    :param filepath_list: List of paths to files to analyse
-    :param expression: Name of the variable (or expression depending on varibales in the TTree) to be checked
-    :param limits: Pre-defined range
-    :param expr_for_subtraction: Name of the control variable (or expression depending on varibales in the TTree)
-    to be used to perform background subtraction
-    :param mean_sig: expected mean value of expr_for_subtraction variable. The signal window will be centered around this value.
-    :param background_shift:  Shift, w.r.t the "mean_sig" value, used to define the two background regions.
-    :param background_window:  Length of the background windows (of expr_for_subtraction variable).
-    :param signal_window: Length of the signal window (of expr_for_subtraction variable) used for background subtraction.
-    The window is centered around the value of "mean_sig".
-    :param n_bins: number of bins for the histogram
-    :param blind_ranges: regions to be blinded in the histogram
-    :param tree_pattern: A regular expression for the TTree object to check
-    :returns: A CheckResult object, containing tree_data key/values:
-      * histograms: a list of filled 1D histograms,
-                    Index 0: the control variable used to perform the subtraction
-                    Index 1: events in the signal window
-                    Index 2: events in the background window
-                    Index 3: the background-subtracted result
+    Check if there is at least one entry in the TTree object with a specific variable falling in a pre-defined range.
+    The background-subtracted histogram is then produced as output. Background is subtracted assuming a linear
+    distribution. In particular, signal ([m-s, m+s]) and background ([m-b-delta, m-b] U [m+b, m+b+delta]) windows have
+    to be defined on a control variable. Then, one histogram is created for events falling in the signal region and
+    another histogram is created for events falling in the background region. The subtraction, using the proper scaling
+    factor, is finally performed. It is also possible to blind some regions.
+
+    Args:
+        filepath_list (list[file-like]): List of paths to files to analyse
+        expression (str): Name of the variable (or expression depending on varibales in the TTree) to be checked
+        limits (dict): Pre-defined range
+        expr_for_subtraction (str): Name of the control variable (or expression depending on varibales in the TTree) to
+            be used to perform background subtraction
+        mean_sig (float): Expected mean value of expr_for_subtraction variable. The signal window will be centered
+            around this value.
+        background_shift (float):  Shift, w.r.t the "mean_sig" value, used to define the two background regions.
+        background_window (float):  Length of the background windows (of expr_for_subtraction variable).
+        signal_window (float): Length of the signal window (of expr_for_subtraction variable) used for background
+            subtraction. The window is centered around the value of "mean_sig".
+        n_bins (int): Number of bins for the histogram
+        blind_ranges (dict): Regions to be blinded in the histogram
+        tree_pattern (regex): A regular expression for the TTree object to check
+
+    Returns:
+        A CheckResult object, which for each tree contains tree_data key/values:
+            histograms: A list of filled 1D histograms,
+                Index 0: The control variable used to perform the subtraction
+                Index 1: Events in the signal window
+                Index 2: Events in the background window
+                Index 3: The background-subtracted result
     """
     result = CheckResult("range_bkg_subtracted", True)
 
@@ -687,7 +723,9 @@ def range_check_bkg_subtracted(
                         background_range_high["max"],
                         name=expr_for_subtraction,
                     )
-                    result.tree_data[key]["histograms"] = [Hist(axis0)]
+                    result.tree_data[key]["histograms"] = [
+                        Hist(axis0, name=f"{key} {expression}")
+                    ]
                     # Add ranges to histogram metadata. Signal and background regions can be then highlighted in the final plot.
                     result.tree_data[key]["histograms"][0].metadata = [
                         background_range_low["min"],
@@ -702,8 +740,12 @@ def range_check_bkg_subtracted(
                     axis1 = hist.axis.Regular(
                         n_bins, limits["min"], limits["max"], name=expression
                     )
-                    result.tree_data[key]["histograms"].append(Hist(axis1))
-                    result.tree_data[key]["histograms"].append(Hist(axis1))
+                    result.tree_data[key]["histograms"].append(
+                        Hist(axis1, name=f"{key} {expression} signal")
+                    )
+                    result.tree_data[key]["histograms"].append(
+                        Hist(axis1, name=f"{key} {expression} background")
+                    )
 
                 values_obj = {}
                 # Check if the branch is in the Tree or if the expressions are correctly written
@@ -828,12 +870,17 @@ def branches_exist(
     branches,
     tree_pattern,
 ):
-    """Check that all matching TTree objects contain a minimum number of entries.
+    """Branches exist check.
 
-    :param filepath_list: List of paths to files to analyse
-    :param branches: List of branches that will be required to exist in TTree objects
-    :param tree_pattern: A regular expression for the TTree objects to check
-    :returns: A CheckResult object, containing no tree_data key/values (empty dict)
+    Check that all matching TTree objects contain a minimum number of entries.
+
+    Args:
+        filepath_list: List of paths to files to analyse
+        branches: List of branches that will be required to exist in TTree objects
+        tree_pattern: A regular expression for the TTree objects to check
+
+    Returns:
+        A CheckResult object, which for each tree contains no tree_data key/values (an empty dict)
     """
     result = CheckResult("branches_exist", True)
     for filepath in filepath_list:
