@@ -1,5 +1,5 @@
 ###############################################################################
-# (c) Copyright 2020 CERN for the benefit of the LHCb Collaboration           #
+# (c) Copyright 2020-2022 CERN for the benefit of the LHCb Collaboration      #
 #                                                                             #
 # This software is distributed under the terms of the GNU General Public      #
 # Licence version 3 (GPL Version 3), copied verbatim in the file "COPYING".   #
@@ -11,4 +11,12 @@
 
 
 def lint_all(data):
+    """Placeholder for linting.
+
+    Args:
+        data: ...
+
+    Raises:
+        NotImplementedError: This function is not implemented.
+    """
     raise NotImplementedError()
