@@ -1,5 +1,5 @@
 ###############################################################################
-# (c) Copyright 2021 CERN for the benefit of the LHCb Collaboration           #
+# (c) Copyright 2021-2022 CERN for the benefit of the LHCb Collaboration      #
 #                                                                             #
 # This software is distributed under the terms of the GNU General Public      #
 # Licence version 3 (GPL Version 3), copied verbatim in the file "COPYING".   #
@@ -17,18 +17,21 @@ from LbAPCommon.parsing import is_simulation_job
 
 
 def validate_options(json_file: str, ntuple_fn: str, job_name: str, prod_data: dict):
-    """
-    Validate existence of expected TTrees and ensure at least one
-    DecayTree and MCDecayTree (for MC samples) exists in output files
+    """Validate YAML options.
 
-    :param json_file: json_file listing the expected TTrees
-    :param ntuple_fn: Local test output tuple to validate against
-    :param job_name: Name of job to validate
-    :param prod_data: Entire production information from yaml parsing
-    :returns: Errors if any expected TTrees are not found in job output,
-              warnings if at least one (MC)DecayTree isn't found in job output
-    """
+    Check existence of expected TTrees and ensure at least one
+    DecayTree and MCDecayTree (for MC samples) exist(s) in output files.
 
+    Args:
+        json_file (str): json_file listing the expected TTrees
+        ntuple_fn (str): Local test output tuple to validate against
+        job_name (str): Name of job to validate
+        prod_data (dict): Entire production information from yaml parsing
+
+    Returns:
+        tuple[list[str]]: Errors if any expected TTrees are not found in job output,
+            warnings if at least one (MC)DecayTree isn't found in job output
+    """
     with open(json_file, "rb") as fp:
         json_dump = json.load(fp)
 
