@@ -1,5 +1,5 @@
 ###############################################################################
-# (c) Copyright 2021 CERN for the benefit of the LHCb Collaboration           #
+# (c) Copyright 2021-2022 CERN for the benefit of the LHCb Collaboration      #
 #                                                                             #
 # This software is distributed under the terms of the GNU General Public      #
 # Licence version 3 (GPL Version 3), copied verbatim in the file "COPYING".   #
@@ -9,9 +9,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 
-# This file needs to support Python 2 to maintain support for the legacy stacks
-from __future__ import print_function
-
 import json
 import pickle
 import pprint
@@ -25,6 +22,11 @@ from DecayTreeTupleBase.DecayTreeTupleBaseConf import (
 
 
 def parse_args():
+    """Parse command line arguments with `argparse`.
+
+    Returns:
+        ArgumentParser-parsed arguments.
+    """
     parser = ArgumentParser()
     parser.add_argument("--pkl", required=True, help="Pickle file to read")
     parser.add_argument("--output", required=True, help="Name of output .json file")
@@ -34,9 +36,14 @@ def parse_args():
     return parser.parse_args()
 
 
-def pkl_json_dump(pkl, output, debug):
-    "Move relevant information from pickle to json format"
+def pkl_json_dump(pkl, output, debug=False):
+    """Move relevant information from pickle to JSON format.
 
+    Args:
+        pkl (str): Pickle file path.
+        output (str): Output JSON file path.
+        debug (bool, optional): Debug flag. Defaults to False.
+    """
     output_dict = {"DecayTreeTuple": [], "MCDecayTreeTuple": [], "EventTuple": []}
 
     # Open the pickle file
@@ -65,4 +72,4 @@ if __name__ == "__main__":
 
     args = parse_args()
 
-    pkl_json_dump(args.pkl, args.output, args.debug)
+    pkl_json_dump(args.pkl, args.output, debug=args.debug)
