@@ -36,11 +36,17 @@ RE_CONDDB_TAG = r"^.{1,50}$"
 RE_COMMENT = r"(.{1,5000})"
 DQ_FLAGS_SCHEMA = Seq(Enum(["BAD", "OK", "EXPRESS_OK", "UNCHECKED"]))
 
+LBEXEC_OPTIONS = {
+    "entrypoint": Regex(r".+:.+"),
+    Optional("extra_options"): MapPattern(Str(), Any()),
+    Optional("extra_args"): Seq(str),
+}
+
 BASE_JOB_SCHEMA = {
     "application": Regex(RE_APPLICATION),
     "input": MapPattern(Str(), Any()),
     "output": Regex(RE_OUTPUT_FILE_TYPE) | Seq(Regex(RE_OUTPUT_FILE_TYPE)),
-    "options": Regex(RE_OPTIONS_FN) | Seq(Regex(RE_OPTIONS_FN)),
+    "options": Regex(RE_OPTIONS_FN) | Seq(Regex(RE_OPTIONS_FN)) | Map(LBEXEC_OPTIONS),
     "wg": Enum(config.known_working_groups),
     "inform": Regex(RE_INFORM) | Seq(Regex(RE_INFORM)),
     # Automatic configuration
@@ -622,7 +628,7 @@ def validate_yaml(jobs_data, checks_data, repo_root, prod_name):
 def _validate_job_data(repo_root, prod_name, job_name, job_data, checks_data):
     # Normalise list/str fields to always be lists
     for prop in ["output", "options", "inform", "checks", "extra_checks"]:
-        if not isinstance(job_data.get(prop, []), list):
+        if not isinstance(job_data.get(prop, []), (list, dict)):
             job_data[prop] = [job_data[prop]]
 
     # Validate the input data
@@ -634,25 +640,26 @@ def _validate_job_data(repo_root, prod_name, job_name, job_data, checks_data):
         _normalise_filetype(prod_name, job_name, s) for s in job_data["output"]
     ]
 
-    # Normalise the options filenames
-    normalised_options = []
-    for fn in job_data["options"]:
-        if fn.startswith("$"):
-            normalised_options.append(fn)
-            continue
+    # Normalise the options filenames if we're using a non-PyConf application
+    if isinstance(job_data["options"], list):
+        normalised_options = []
+        for fn in job_data["options"]:
+            if fn.startswith("$"):
+                normalised_options.append(fn)
+                continue
 
-        fn_normed = relpath(join(repo_root, fn), start=repo_root)
-        if fn_normed.startswith("../"):
-            raise ValueError(f"{fn} not found inside {repo_root}")
-        if not isfile(join(repo_root, prod_name, fn_normed)):
-            raise FileNotFoundError(
-                f"Production {job_name!r} has a missing options file: "
-                f"{join(prod_name, fn_normed)!r}",
+            fn_normed = relpath(join(repo_root, fn), start=repo_root)
+            if fn_normed.startswith("../"):
+                raise ValueError(f"{fn} not found inside {repo_root}")
+            if not isfile(join(repo_root, prod_name, fn_normed)):
+                raise FileNotFoundError(
+                    f"Production {job_name!r} has a missing options file: "
+                    f"{join(prod_name, fn_normed)!r}",
+                )
+            normalised_options.append(
+                join("$ANALYSIS_PRODUCTIONS_BASE", prod_name, fn_normed)
             )
-        normalised_options.append(
-            join("$ANALYSIS_PRODUCTIONS_BASE", prod_name, fn_normed)
-        )
-    job_data["options"] = normalised_options
+        job_data["options"] = normalised_options
 
     # Validate the check names
     # All checks listed for jobs should match a check defined in checks_data
